==> haskell-persistent-template-2.1.6-16-armv7h.pkg.tar.xz: usr/share/haskell/haskell-persistent-template/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-template
version: 2.1.6
id: persistent-template-2.1.6-83163c252d18f4a1e745e383b4fcf281
key: persi_GsKSAAfCBGV1Lsexm42ruO
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, non-relational, multi-backend persistence.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent-template>.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Database.Persist.TH
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-template-2.1.6
library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-template-2.1.6
data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-template-2.1.6
hs-libraries: HSpersistent-template-2.1.6-GsKSAAfCBGV1Lsexm42ruO
depends:
    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
    aeson-compat-0.3.3.0-52f5c04d7d0fac842ea3a64bb05beba5
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    http-api-data-0.2.2-d85b0db99d6d5995d772ab01cd2ae49e
    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
    monad-logger-0.3.18-f3d00babf6bfa7ff698db362dc267041
    path-pieces-0.2.1-f62a4ee86afe2692f9fb79d2dd895499
    persistent-2.2.4.1-d8d907c8c62628a6667ab3fa39fc892f
    tagged-0.8.4-af2e23230031c45949e0062e776a8f1f
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
haddock-interfaces: /usr/share/doc/haskell-persistent-template/html/persistent-template.haddock
haddock-html: /usr/share/doc/haskell-persistent-template/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-template-2.1.6-17-armv7h.pkg.tar.xz: usr/share/haskell/haskell-persistent-template/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-template
version: 2.1.6
id: persistent-template-2.1.6-0f50ab49755373ba8c00624f7c433aaf
key: persi_0likh8TCIAC7laYhDTyGqz
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, non-relational, multi-backend persistence.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent-template>.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Database.Persist.TH
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-template-2.1.6
library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-template-2.1.6
data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-template-2.1.6
hs-libraries: HSpersistent-template-2.1.6-0likh8TCIAC7laYhDTyGqz
depends:
    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
    aeson-compat-0.3.3.0-52f5c04d7d0fac842ea3a64bb05beba5
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    http-api-data-0.2.2-d85b0db99d6d5995d772ab01cd2ae49e
    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
    monad-logger-0.3.18-1374b457a8b7165408364c0bd477c532
    path-pieces-0.2.1-f62a4ee86afe2692f9fb79d2dd895499
    persistent-2.2.4.1-53b32e0b8931dd68fbb356ac374c65f3
    tagged-0.8.4-af2e23230031c45949e0062e776a8f1f
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
haddock-interfaces: /usr/share/doc/haskell-persistent-template/html/persistent-template.haddock
haddock-html: /usr/share/doc/haskell-persistent-template/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
